Type: Package
Package: BioGA
Title: Bioinformatics Genetic Algorithm (BioGA)
Version: 1.4.0
Authors@R: 
    person("Dany", "Mukesha", , "danymukesha@gmail.com", 
            role = c("aut", "cre"),
           comment = c(ORCID = "0009-0001-9514-751X"))
Description: Genetic algorithm are a class of optimization algorithms
    inspired by the process of natural selection and genetics. This
    package allows users to analyze and optimize high throughput genomic
    data using genetic algorithms.  The functions provided are implemented
    in C++ for improved speed and efficiency, with an easy-to-use
    interface for use within R.
License: MIT + file LICENSE
URL: https://danymukesha.github.io/BioGA/
BugReports: https://github.com/danymukesha/BioGA/issues
Imports: ggplot2, graphics, Rcpp, SummarizedExperiment, animation,
        rlang, biocViews, sessioninfo, BiocStyle
Depends: R (>= 4.4)
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
LinkingTo: Rcpp
VignetteBuilder: knitr
biocViews: ExperimentalDesign, Technology
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.1
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/BioGA
git_branch: RELEASE_3_22
git_last_commit: d779378
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 02:49:26 UTC; biocbuild
Author: Dany Mukesha [aut, cre] (ORCID:
    <https://orcid.org/0009-0001-9514-751X>)
Maintainer: Dany Mukesha <danymukesha@gmail.com>
