# Generated by roxygen2: do not edit by hand

export(crossover_cpp)
export(evaluate_fitness_cpp)
export(initialize_population_cpp)
export(mutation_cpp)
export(plot_fitness)
export(plot_fitness_history)
export(plot_population)
export(replacement_cpp)
export(selection_cpp)
importFrom(BiocStyle,html_document)
importFrom(Rcpp,evalCpp)
importFrom(Rcpp,sourceCpp)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(animation,saveGIF)
importFrom(biocViews,getBiocViews)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(graphics,boxplot)
importFrom(graphics,hist)
importFrom(graphics,par)
importFrom(rlang,local_options)
importFrom(sessioninfo,session_info)
useDynLib(BioGA, .registration = TRUE)
