#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom biocViews getBiocViews
#' @importFrom ggplot2 ggtitle ggplot geom_line labs
#' @importFrom sessioninfo session_info
#' @importFrom SummarizedExperiment SummarizedExperiment
#' @importFrom Rcpp evalCpp sourceCpp
#' @importFrom graphics boxplot hist par
#' @importFrom animation saveGIF
#' @importFrom rlang local_options
#' @importFrom BiocStyle html_document
#' @useDynLib BioGA, .registration = TRUE
## usethis namespace: end
NULL
